# from .main import *

# __copyright__    = 'Copyright (C) 2013 tiiday. All rights reserved'
# __version__      = '1.0.0'
# __license__      = ''
# __author__       = 'tiida'
# __author_email__ = 'tiida@Email'
# __url__          = 'http://github.com/account/repository'

# __all__ = ['公開モジュール', ...]
