
class tiida(object):
    def __init__(self):
        self.name = 'tiida'
        self.height = 178
        self.weight = 77

    def hello_tiida(self):
        print(f"hello {self.name}")
        return f"hello {self.name}"

def hello_tiida():
    print('hello tiida')
